library(igraph)
node <- read.table("node.txt",head=T)
rel <- read.table("relation.txt",head=T)

g <- graph.empty()
g <- add.vertices(g,nrow(node),name=as.character(node[,1]),class=as.character(node[,2]))
names <- V(g)$name
ids <- 1:length(names)-1
names(ids) <- names

from <- as.character(rel[,1])
to <- as.character(rel[,2])
edges <- matrix(c(ids[from],ids[to]),nc=2)
g <- add.edges(g,t(edges),anno=as.character(rel[,3]))

E(g)$color <- "black"
E(g)[anno=="F"]$color <- "red"
V(g)[class=="F"]$color <- "green"
V(g)[class=="G"]$color <- "blue"
V(g)$label <- V(g)$name

tiff("tf_tg.tiff",height=4800,width=4800,compression="lzw")
plot(g,layout=layout.fruchterman.reingold,vertex.color=V(g)$color,vertex.label=NA,vertex.size=1,edge.color=E(g)$color,edge.arrow.size=0.5)
dev.off()

lc <- largest.cliques(g)
g.lc <- subgraph(g, lc[[1]])
tiff("tf_tg_lc.tiff",height=4800,width=4800,compression="lzw")
plot(g.lc,layout=layout.fruchterman.reingold,vertex.color=V(g)$color,vertex.size=1,edge.color=E(g)$color,edge.arrow.size=0.5)
dev.off()
